@@ -1,6 +1,6 @@
 #' Class "Detectability" 
 #' 
-#' Class \code{"Detectability"} is an S4 class describing the probablity
+#' Class \code{"Detectability"} is an S4 class describing the probability
 #' of detecting individuals / clusters in a population.
 #'
 #' @name Detectability-class
@@ -28,7 +28,7 @@ setClass("Detectability", representation(key.function    = "character",
 setMethod(
   f="initialize",
   signature="Detectability",
-  definition=function(.Object, key.function, scale.param, shape.param = numeric(0), covariates = character(0), cov.param = numeric(0), truncation = numeric(0)){
+  definition=function(.Object, key.function = "hn", scale.param = 25, shape.param = numeric(0), covariates = character(0), cov.param = numeric(0), truncation = 50){
     #Input pre-processing
     #Set slots
     .Object@key.function <- key.function
